Enum cpp_demangle::error::Error
[−]
[src]
pub enum Error {
UnexpectedEnd,
UnexpectedText,
BadBackReference,
BadTemplateArgReference,
BadFunctionArgReference,
Overflow,
RecursiveDemangling,
TooMuchRecursion,
}Errors that can occur while demangling a symbol.
Variants
UnexpectedEndThe mangled symbol ends abruptly.
UnexpectedTextThe mangled symbol is not well-formed.
BadBackReferenceFound a back reference that is out-of-bounds of the substitution table.
BadTemplateArgReferenceFound a reference to a template arg that is either out-of-bounds, or in a context without template args.
BadFunctionArgReferenceFound a reference to a function arg that is either out-of-bounds, or in a context without function args.
OverflowAn overflow or underflow would occur when parsing an integer in a mangled symbol.
RecursiveDemanglingThe act of demangling some part of the AST attempted to demangle itself again.
TooMuchRecursionEncountered too much recursion when demangling symbol.